@@ -497,24 +497,6 @@ def log_system_info():
     logging.debug(f"Packages:\n{os.popen('pip freeze').read()}")
 
 
-def count_files(
-    external_id_prefix, 
-    directory_prefix='/'
-):
-    """
-    How many files have the given `external_id_prefix` and `directory_prefix`
-    This can be used for file versioning.
-
-    Returns an integer (>=0)
-    """
-    client = global_client["files"]
-    result = client.files.aggregate(filter={
-        "external_id_prefix": external_id_prefix, 
-        "directory_prefix": directory_prefix
-    })
-    return result[0]["count"]
-
-
 def query_file_versions(
     directory_prefix, 
     external_id_prefix, 
